@@ -427,7 +427,7 @@ class OpenEVSE:
 
         _LOGGER.debug("Detected firmware: %s", current)
 
-        if cutoff <= current:
+        if current >= cutoff:
             url = f"{self.url}override"
 
             _LOGGER.debug("Toggling manual override %s", url)
@@ -456,7 +456,7 @@ class OpenEVSE:
         cutoff = AwesomeVersion("4.1.2")
         current = AwesomeVersion(self._config["version"])
 
-        if cutoff <= current:
+        if current >= cutoff:
             url = f"{self.url}config"
 
             if (
@@ -472,9 +472,7 @@ class OpenEVSE:
             response = await self.process_request(
                 url=url, method="post", data=data
             )  # noqa: E501
-            if response["msg"] != "done":
-                _LOGGER.error("Problem issuing command: %s", response["msg"])
-                raise UnknownError
+
         else:
             # RAPI commands
             _LOGGER.debug("Setting current via RAPI")
